@@ -54,6 +54,13 @@ class ArticleName(Element):
     tag = 'ArticleName'
 
 
+class BuyerArticleIdentifier(Element):
+    """
+    BuyerArticleIdentifier
+    """
+    tag = 'BuyerArticleIdentifier'
+    
+
 class DeliveredQuantity(Element):
     """
     DeliveredQuantity
@@ -293,6 +300,7 @@ class InvoiceRow(Element):
         RowSubIdentifier,
         ArticleIdentifier,
         ArticleName,
+        BuyerArticleIdentifier,
         DeliveredQuantity,
         OrderedQuantity,
         ConfirmedQuantity,
@@ -301,6 +309,7 @@ class InvoiceRow(Element):
         RowIdentifier,
         RowIdentifierDate,
         RowDeliveryDate,
+        RowDiscountPercent,
         RowAgreementIdentifier,
         RowRequestOfQuotationIdentifier,
         RowPriceListIdentifier,
