@@ -112,6 +112,14 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         payee = self.wrapper.payee
         self.assertEqual(payee.fax, '(09) 1232500')
 
+    def test_seller_freetext(self):
+        """
+        test_seller_freetext
+        """
+        payee = self.wrapper.payee
+        self.assertEqual(payee.seller_free_text, \
+                         u'Meidän kanssa kannattaa tehdä kauppaa')
+
     def test_payee_bank_swift_code(self):
         """
         test_payee_bank_swift_code
@@ -375,6 +383,16 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         invoice = self.wrapper.invoice
         self.assertEqual(invoice.buyer_reference_identifier, None)
 
+    def test_specification_free_text(self):
+        """
+        test_spesification_free_text
+        """
+        invoice = self.wrapper.invoice
+        text = u'LASKUN VAPAAMUOTOISET ERITTELYTIEDOT:\nSarake-1              Sarake-2                                                             Sarake-3\n---------------------------------------------------------------------------------------------------\n1.sarakkeen tieto     2.sarakkeen tieto                                                       10,00\nToinen rivi           Toinen rivi                                                          1 000,00\nKolmas rivi           3/2                                                                      1,00\nMuotoituja tietoja voidaan käyttää mm.tarkemman erittelyn esittämiseen:\n'
+        self.assertEqual(invoice.specification_free_text, text)
+
+
+
     def test_invoice_free_text(self):
         """
         test_invoice_free_text
@@ -456,6 +474,7 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(row.vat_amount, Decimal("63.12"))
         self.assertEqual(row.vat_amount_currency, 'EUR')
         self.assertEqual(row.vat_percent, Decimal('22'))
+        self.assertEqual(row.discount_percent, None)
         self.assertEqual(row.unit_code, 'kpl')
         self.assertEqual(row.freetext,
             u'Tuote myydään varsien ja ohjeen kanssa.\n')
@@ -482,7 +501,9 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(row.vat_percent, Decimal('22'))
         self.assertEqual(row.unit_code, 'kpl')
         self.assertEqual(row.account_dimension_text, None)
-
+        self.assertEqual(row.identifier, 'TI22122')
+        self.assertEqual(row.buyer_article_identifier, None)
+        self.assertEqual(row.agreement_identifier, None)
 
     def test_rows_2(self):
         """
@@ -500,10 +521,14 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(row.total_untaxed, None)
         self.assertEqual(row.total_untaxed_currency, None)
         self.assertEqual(row.vat_amount, None)
+        self.assertEqual(row.discount_percent, None)
         self.assertEqual(row.vat_amount_currency, None)
         self.assertEqual(row.vat_percent, None)
         self.assertEqual(row.unit_code, None)
         self.assertEqual(row.account_dimension_text, None)
+        self.assertEqual(row.identifier, None)
+        self.assertEqual(row.buyer_article_identifier, None)
+        self.assertEqual(row.agreement_identifier, None)
 
     def test_rows_5(self):
         """
@@ -520,9 +545,13 @@ class TestFinvoiceWrapperWithPulliFinvoice(FinvoiceTestCase):
         self.assertEqual(row.total_untaxed_currency, 'EUR')
         self.assertEqual(row.vat_amount, Decimal('498.35'))
         self.assertEqual(row.vat_amount_currency, 'EUR')
+        self.assertEqual(row.discount_percent, Decimal('2'))
         self.assertEqual(row.vat_percent, Decimal('22'))
         self.assertEqual(row.unit_code, 'kpl')
         self.assertEqual(row.account_dimension_text, '4500')
+        self.assertEqual(row.identifier, 'TIL3123')
+        self.assertEqual(row.buyer_article_identifier, None)
+        self.assertEqual(row.agreement_identifier, None)
 
 
     def test_delivery_party_contact_email(self):
