@@ -62,6 +62,7 @@ class Invoice(object):
     order_identifier = None
     seller_reference_identifier = None
     buyer_reference_identifier = None
+    specification_free_text = None
 
     def set_epi_details(self, doc):
         epi_details = doc.EpiDetailsSet
@@ -151,10 +152,27 @@ class Invoice(object):
             if len(free_text) > 0:
                 self.free_text = free_text.as_string(delim='\n')
 
+    def set_specification_details(self, doc):
+        specification_details = doc.SpecificationDetailsSet
+        if len(specification_details) > 0:
+            """
+            specification_free_text = \
+                                 specification_details[0].SpecificationFreeTextSet
+            if len(specification_free_text) > 0:
+                 self.specification_free_text = \
+                                  specification_free_text.as_string(delim='\n')
+            """
+
+            for element in specification_details[0].SpecificationFreeTextSet:
+                if not self.specification_free_text:
+                    self.specification_free_text = ''
+                self.specification_free_text += '%s\n' % ((element.text or ''), )
+
     def __init__(self, doc):
 
         self.set_epi_details(doc)
         self.set_invoice_details(doc)
+        self.set_specification_details(doc)
 
 
 class PostalAddress(object):
@@ -343,6 +361,7 @@ class Payee(object):
     organisation_taxcode = ''
     bank_accounts = None
     intermediator = None
+    seller_free_text = None
 
     def __init__(self, doc, envelope=None):
         if envelope:
@@ -391,6 +410,10 @@ class Payee(object):
                 acc = BankAccount(account_number, swift_code)
                 self.bank_accounts.append(acc)
 
+            seller_free_text = info_details[0].SellerFreeTextSet
+            if len(seller_free_text) > 0:
+                self.seller_free_text = seller_free_text.as_string(delim='\n')
+
         org_unit_number = doc.SellerOrganisationUnitNumberSet
         if len(org_unit_number) > 0:
             self.organisation_unit_number = org_unit_number[0].text
@@ -435,6 +458,7 @@ class Payee(object):
             if len(email) > 0:
                 self.contact_email = email[0].text
 
+                 
 
 class Payer(object):
 
@@ -531,6 +555,10 @@ class Row(object):
     freetext = None
     article_identifier = None
     account_dimension_text = None
+    discount_percent = None
+    identifier = None
+    buyer_article_identifier = None
+    agreement_identifier = None
 
     def __init__(self, row):
         self.name = row.ArticleNameSet.as_string()
@@ -608,6 +636,22 @@ class Row(object):
         if len(account_dimension_text) > 0:
             self.account_dimension_text = account_dimension_text[0].text
 
+        discount_percent = row.RowDiscountPercentSet
+        if len(discount_percent) > 0:
+            self.discount_percent = _Decimal(discount_percent[0].text.strip())
+
+        identifier = row.RowIdentifierSet
+        if len(identifier) > 0:
+            self.identifier = identifier[0].text
+
+        buyer_article_identifier = row.BuyerArticleIdentifierSet
+        if len(buyer_article_identifier) > 0:
+            self.buyer_article_identifier = buyer_article_identifier[0].text
+
+        agreement_identifier = row.RowAgreementIdentifierSet
+        if len(agreement_identifier) > 0:
+            self.agreement_identifier = agreement_identifier[0].text
+
         date_id = row.RowIdentifierDateSet
         delivery_date = row.RowDeliveryDateSet
         if len(date_id) > 0:
